@@ -43,6 +43,6 @@ fn main() {
         }
 
         // Include a new line
-        println!("");
+        println!();
     });
 }
