@@ -2,10 +2,10 @@ use std::io;
 use std::rc::Rc;
 use tokio::task::JoinHandle;
 
-pub const RESPONSE: &'static [u8] =
+pub const RESPONSE: &[u8] =
     b"HTTP/1.1 200 OK\nContent-Type: text/plain\nContent-Length: 12\n\nHello world!";
 
-pub const ADDRESS: &'static str = "127.0.0.1:8080";
+pub const ADDRESS: &str = "127.0.0.1:8080";
 
 fn main() -> io::Result<()> {
     tokio_uring::start(async {
@@ -21,7 +21,7 @@ fn main() -> io::Result<()> {
                     let (stream, _) = listener.accept().await?;
 
                     tokio_uring::spawn(async move {
-                        let (result, _) = stream.write(RESPONSE).await;
+                        let (result, _) = stream.write(RESPONSE).submit().await;
 
                         if let Err(err) = result {
                             eprintln!("Client connection failed: {}", err);
